flamingo
========

.. image:: doc/content/images/flamingo.svg
    :height: 128px
    :width: 128px

|

.. image:: https://img.shields.io/pypi/l/flamingo.svg
    :alt: pypi.org
    :target: https://pypi.org/project/flamingo
.. image:: https://github.com/pengutronix/flamingo/actions/workflows/ci.yaml/badge.svg
    :alt: CI Test Status
    :target: https://github.com/pengutronix/flamingo/actions/workflows/ci.yaml
.. image:: https://github.com/pengutronix/flamingo/actions/workflows/docs.yml/badge.svg
    :alt: Documentation Build Status
    :target: https://github.com/pengutronix/flamingo/actions/workflows/docs.yml
.. image:: https://img.shields.io/pypi/pyversions/flamingo.svg
    :alt: pypi.org
    :target: https://pypi.org/project/flamingo
.. image:: https://img.shields.io/pypi/v/flamingo.svg
    :alt: pypi.org
    :target: https://pypi.org/project/flamingo
.. image:: https://img.shields.io/codecov/c/github/pengutronix/flamingo.svg
    :alt: codecov.io
    :target: https://codecov.io/gh/pengutronix/flamingo/


Flamingo is a python3-based, pelican-inspired static site generator, made by
`Pengutronix <https://www.pengutronix.de>`__

Websites powered by flamingo:
 - `pengutronix.de <https://www.pengutronix.de>`__
 - `linux-automation.com <https://www.linux-automation.com/de/>`__

Documentation: `flamingo-web.org <https://flamingo-web.org>`__
